==> ipyregulartable-0.1.2.tar.gz: package/lib/model.js <==
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/******************************************************************************
 *
 * Copyright (c) 2020, the ipyregulartable authors.
 *
 * This file is part of the jupyterlab_templates library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
/* eslint-disable @typescript-eslint/explicit-member-accessibility */
/* eslint-disable @typescript-eslint/tslint/config */
/* eslint-disable @typescript-eslint/explicit-function-return-type */
const base_1 = require("@jupyter-widgets/base");
const version_1 = require("./version");
class RegularTableModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: RegularTableModel.modelName, _model_module: RegularTableModel.modelModule, _model_module_version: RegularTableModel.modelModuleVersion, _view_name: RegularTableModel.viewName, _view_module: RegularTableModel.viewModule, _view_module_version: RegularTableModel.viewModuleVersion, height: 200, css: {
                table: "",
                thead: "",
                theadtr: "",
                theadth: "",
                tbody: "",
                tbodytr: "",
                tbodyth: "",
                tbodytd: "",
            }, styler: {
                table: {
                    expression: [],
                    style: [],
                },
                thead: {
                    expression: [],
                    style: [],
                },
                tr: {
                    expression: [],
                    style: [],
                },
                th: {
                    expression: [],
                    style: [],
                },
                td: {
                    expression: [],
                    style: [],
                },
                theadtr: {
                    expression: [],
                    style: [],
                },
                theadth: {
                    expression: [],
                    style: [],
                },
                tbody: {
                    expression: [],
                    style: [],
                },
                tbodytr: {
                    expression: [],
                    style: [],
                },
                tbodyth: {
                    expression: [],
                    style: [],
                },
            }, _data: {}, _editable: false });
    }
}
exports.RegularTableModel = RegularTableModel;
RegularTableModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
RegularTableModel.modelName = "RegularTableModel";
RegularTableModel.modelModule = "ipyregulartable";
RegularTableModel.modelModuleVersion = version_1.MODULE_VERSION;
RegularTableModel.viewName = "RegularTableView"; // Set to null if no view
RegularTableModel.viewModule = "ipyregulartable"; // Set to null if no view
RegularTableModel.viewModuleVersion = version_1.MODULE_VERSION;
//# sourceMappingURL=model.js.map

==> ipyregulartable-0.2.0.tar.gz: package/lib/model.js <==
/******************************************************************************
 *
 * Copyright (c) 2020, the ipyregulartable authors.
 *
 * This file is part of the jupyterlab_templates library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
/* eslint-disable @typescript-eslint/explicit-member-accessibility */
/* eslint-disable @typescript-eslint/tslint/config */
/* eslint-disable @typescript-eslint/explicit-function-return-type */
import { DOMWidgetModel } from "@jupyter-widgets/base";
import { MODULE_VERSION } from "./version";
export class RegularTableModel extends DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: RegularTableModel.modelName, _model_module: RegularTableModel.modelModule, _model_module_version: RegularTableModel.modelModuleVersion, _view_name: RegularTableModel.viewName, _view_module: RegularTableModel.viewModule, _view_module_version: RegularTableModel.viewModuleVersion, height: 200, css: {
                table: "",
                thead: "",
                theadtr: "",
                theadth: "",
                tbody: "",
                tbodytr: "",
                tbodyth: "",
                tbodytd: "",
            }, styler: {
                table: {
                    expression: [],
                    style: [],
                },
                thead: {
                    expression: [],
                    style: [],
                },
                tr: {
                    expression: [],
                    style: [],
                },
                th: {
                    expression: [],
                    style: [],
                },
                td: {
                    expression: [],
                    style: [],
                },
                theadtr: {
                    expression: [],
                    style: [],
                },
                theadth: {
                    expression: [],
                    style: [],
                },
                tbody: {
                    expression: [],
                    style: [],
                },
                tbodytr: {
                    expression: [],
                    style: [],
                },
                tbodyth: {
                    expression: [],
                    style: [],
                },
            }, _data: {}, _editable: false });
    }
}
RegularTableModel.serializers = Object.assign({}, DOMWidgetModel.serializers);
RegularTableModel.modelName = "RegularTableModel";
RegularTableModel.modelModule = "ipyregulartable";
RegularTableModel.modelModuleVersion = MODULE_VERSION;
RegularTableModel.viewName = "RegularTableView"; // Set to null if no view
RegularTableModel.viewModule = "ipyregulartable"; // Set to null if no view
RegularTableModel.viewModuleVersion = MODULE_VERSION;
//# sourceMappingURL=model.js.map
